<?php $TRANSLATIONS = array(
"Save" => "Uložiť",
"Search:" => "Hľadať:",
"Close" => "Zatvoriť",
"Next" => "Ďalšia",
"Clear" => "Vyčistiť",
"Saving..." => "Ukladám...",
"Failed to save file" => "Nepodarilo sa uložiť súbor",
"An error occurred!" => "Vyskytla sa chyba!",
"There were unsaved changes, click here to go back" => "Zostali neuložené zmeny. Kliknite sem pre návrat."
);
